==> haskell-either-5.0.1.1-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1.1
id: either-5.0.1.1-2VKwsQfBk468OCmiRorzav
key: either-5.0.1.1-2VKwsQfBk468OCmiRorzav
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: 9ca9ed274ae8615c61c8e0cbd108240c
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/either-5.0.1.1
hs-libraries: HSeither-5.0.1.1-2VKwsQfBk468OCmiRorzav
depends:
    base-4.12.0.0 bifunctors-5.5.5-B9uCrLlHHzRLLgqunxnstR mtl-2.2.2
    profunctors-5.5-AsNt6U9QGtDLU0jWBMm4n8
    semigroupoids-5.3.3-5c90p3ZZL5SEVl9HRh2nSh
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.1.1-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1.1
id: either-5.0.1.1-KPZBivNBmmz2nP79jcor1t
key: either-5.0.1.1-KPZBivNBmmz2nP79jcor1t
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: d3f41366f312a9aacbc9cbffa0188de8
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/either-5.0.1.1
hs-libraries: HSeither-5.0.1.1-KPZBivNBmmz2nP79jcor1t
depends:
    base-4.12.0.0 bifunctors-5.5.5-B9uCrLlHHzRLLgqunxnstR mtl-2.2.2
    profunctors-5.5-AsNt6U9QGtDLU0jWBMm4n8
    semigroupoids-5.3.3-FkdTytnn6AH9kiDvzMaHUY
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
